library(UpSetR)

# values correspond to features transferred between nipponbare and azucena by grannot, liftoff, vg and odgi
# values come from the notebook "compare_genome_transfers.ipynb"

# Datasets

# {'odgi_grannot_vg_liftoff': 663665, 'odgi_grannot_liftoff': 60473, 'vg': 73134, 'odgi_grannot': 9401, 'liftoff': 50035, 'odgi': 38363, 
# 'odgi_grannot_vg': 5123, 'grannot': 4555, 'grannot_liftoff': 1029, 'liftoff_vg': 659, 'odgi_liftoff_vg': 1428, 'odgi_liftoff': 707,
# 'grannot_vg_liftoff': 10138, 'grannot_vg': 130, 'odgi_vg': 128}

# two transfers are considered equal if they placed a feature at the exact same position
input_0 <- c(
  VG = 73134,
  Liftoff = 50035,
  ODGI = 38363,
  GrAnnoT = 4555,
  "ODGI&GrAnnoT" = 9401,
  "VG&Liftoff" = 659,
  "VG&ODGI" = 128,
  "Liftoff&GrAnnoT" = 1029,
  "Liftoff&ODGI" = 707,
  "VG&GrAnnoT" = 130,
  "Liftoff&ODGI&GrAnnoT" = 60473,
  "VG&ODGI&GrAnnoT" = 5123,
  "VG&Liftoff&ODGI" = 1428,
  "VG&Liftoff&GrAnnoT" = 10138,
  "VG&Liftoff&ODGI&GrAnnoT" = 663665
)



# {'odgi_vg_grannot_liftoff': 682711, 'odgi_grannot_liftoff': 44370, 'vg': 55037, 'odgi_grannot': 8750, 'liftoff': 49322, 'odgi': 37726, 
# 'odgi_vg_grannot': 5588, 'odgi_liftoff': 80, 'grannot': 1891, 'grannot_liftoff': 722, 'vg_liftoff': 524, 'odgi_vg': 28, 
# 'odgi_vg_liftoff': 35, 'vg_grannot_liftoff': 10370, 'vg_grannot': 112}

# two transfers are considered equal if they placed a feature at a maximum distance of 1 bp
input_1 <- c(
  VG = 55037,
  Liftoff = 49322,
  ODGI = 37726,
  GrAnnoT = 1891,
  "ODGI&GrAnnoT" = 8750,
  "VG&Liftoff" = 524,
  "VG&ODGI" = 28,
  "Liftoff&GrAnnoT" = 722,
  "Liftoff&ODGI" = 80,
  "VG&GrAnnoT" = 112,
  "Liftoff&ODGI&GrAnnoT" = 44370,
  "VG&ODGI&GrAnnoT" = 5588,
  "VG&Liftoff&ODGI" = 35,
  "VG&Liftoff&GrAnnoT" = 10370,
  "VG&Liftoff&ODGI&GrAnnoT" = 682711
)



# {'vg_liftoff_odgi_grannot': 711788, 'liftoff_odgi_grannot': 17955, 'vg': 25374, 'odgi_grannot': 6318, 'liftoff': 46696, 'odgi': 37195, 
#'vg_odgi_grannot': 6009, 'vg_liftoff': 467, 'grannot': 1083, 'vg_odgi': 10, 'liftoff_grannot': 604, 'vg_liftoff_grannot': 10611,
# 'liftoff_odgi': 13, 'vg_grannot': 146}

# two transfers are considered equal if they placed a feature at a maximum distance of 10 bp
input_10 <- c(
  VG = 25374,
  Liftoff = 46696,
  ODGI = 37195,
  GrAnnoT = 1083,
  "ODGI&GrAnnoT" = 6318,
  "VG&Liftoff" = 467,
  "VG&ODGI" = 10,
  "Liftoff&GrAnnoT" = 604,
  "Liftoff&ODGI" = 13,
  "VG&GrAnnoT" = 146,
  "Liftoff&ODGI&GrAnnoT" = 17955,
  "VG&ODGI&GrAnnoT" = 6009,
  "VG&Liftoff&GrAnnoT" = 10611,
  "VG&Liftoff&ODGI&GrAnnoT" = 711788
)



# {'liftoff_grannot_vg_odgi': 725064, 'grannot_odgi': 4890, 'vg': 11421, 'liftoff': 45270, 'odgi': 36829, 'grannot_vg_odgi': 6416, 
# 'grannot_liftoff_odgi': 6063, 'liftoff_grannot_vg': 10687, 'grannot_liftoff': 366, 'liftoff_vg': 660, 'grannot': 873, 'liftoff_odgi': 24, 
# 'grannot_vg': 155, 'vg_odgi': 2}

# two transfers are considered equal if they placed a feature at a maximum distance of 50 bp
input_50 <- c(
  VG = 11421,
  Liftoff = 45270,
  ODGI = 36829,
  GrAnnoT = 873,
  "ODGI&GrAnnoT" = 4890,
  "VG&Liftoff" = 660,
  "VG&ODGI" = 2,
  "Liftoff&GrAnnoT" = 366,
  "Liftoff&ODGI" = 24,
  "VG&GrAnnoT" = 155,
  "Liftoff&ODGI&GrAnnoT" = 6063,
  "VG&ODGI&GrAnnoT" = 6416,
  "VG&Liftoff&GrAnnoT" = 10687,
  "VG&Liftoff&ODGI&GrAnnoT" = 725064
)

# Plot
dataset=input_10
upset(fromExpression(dataset),
      nintersects = length(dataset),
      nsets = 4,
      order.by = "freq",
      decreasing = T,
      mb.ratio = c(0.7, 0.3),
      number.angles = 0,
      point.size = 4,
      text.scale = c(1.5, 1.3, 1.2, 1, 1.5, 1.2)
)